function areasOnCrystal = f_crystalCreateAreas(vertices,verticesIn,disconnectedVertices,crossingPoints,shiftToRVE)
%
% creates areas from the vertices and points of intersection with RVE
% boundary
%
% areasOnCrystal = f_crystalCreateAreas(vertices,verticesIn,disconnectedVertices,crossingPoints)
%
% written by Venca 13/8/2013

% areas in uncut hexagonal prism
areas(1).vertices = [1,7,8,2];
areas(2).vertices = [2,8,9,3];
areas(3).vertices = [3,9,10,4];
areas(4).vertices = [4,10,11,5];
areas(5).vertices = [5,11,12,6];
areas(6).vertices = [6,12,7,1];
areas(7).vertices = [1,2,3,4,5,6];
areas(8).vertices = [7,8,9,10,11,12];

areasOnCrystal = struct;
counterAreas = 0;

envelope = vertices(verticesIn,:);
envelope = envelope+ones(size(envelope,1),1)*shiftToRVE;
areasOnCrystal.centroid = sum(envelope)/size(envelope,1);
    
for i = 1:8                         % go through all possible areas within the crystal
    actualArea = areas(i).vertices;
    actualVertices = [];
    actualVerticesCoord = [];
    
    for j = 1:length(actualArea)    % for each entry from the area find whether the vertices are "in" or "disconnected"
        testIsIn = false;
        for k = 1:length(verticesIn) % go through all verticesIn
            if actualArea(j) == verticesIn(k)
                actualVertices = [actualVertices, actualArea(j)];
                testIsIn = true;
            end
        end
        
        if ~testIsIn
            for k = 1:size(disconnectedVertices,1)
                for l = 1:2
                    if actualArea(j) == disconnectedVertices(k,l)
                        actualVertices = [actualVertices, 100+k];
                    end
                end
            end
        end
   
    end

    if ~isempty(actualVertices) && ~isempty(actualVertices(actualVertices < 100))
        for l = 1:length(actualVertices)
            if actualVertices(l) < 100
                actualVerticesCoord = [actualVerticesCoord; vertices(actualVertices(l),:)+shiftToRVE]; % write the coordinates of individual vertices into the matrix "actualArea"
            else
                actualVerticesCoord = [actualVerticesCoord; crossingPoints(actualVertices(l)-100,:)];
            end
        end
        counterAreas = counterAreas+1;
        areasOnCrystal(counterAreas).area = actualVerticesCoord; % save the coordinates of the area into structure areasOnCrystal
    end  

end

% save the area at the RVE boundary
if size(crossingPoints,1) > 0
    counterAreas = counterAreas+1;
    
    inPlaneCols = find(round(1e8*crossingPoints(1,:))/1e8 ~= round(1e8*crossingPoints(2,:))/1e8);
    crossingPointsInPlane = crossingPoints(:,inPlaneCols);
    centroid_1 = sum(crossingPointsInPlane(:,1))/length(crossingPointsInPlane(:,1));
    centroid_2 = sum(crossingPointsInPlane(:,2))/length(crossingPointsInPlane(:,2));
    crossingPointsInPlaneCentered = crossingPointsInPlane-[centroid_1*ones(length(crossingPointsInPlane(:,1)),1),centroid_2*ones(length(crossingPointsInPlane(:,2)),1)];
    
    [theta, ~] = cart2pol(crossingPointsInPlaneCentered(:,1),crossingPointsInPlaneCentered(:,2));
    for i = 1:length(theta)
        if theta(i) < 0
            theta(i) = theta(i)+2*pi;
        end
    end
    
    position = zeros(size(theta));
    thetaSorted = sort(theta); 
    for i = 1:length(theta)
        for j = 1:length(thetaSorted)
            if theta(i) == thetaSorted(j)
                position(i) = j;
            end
        end
    end
    
    sortedCrossingPoints = zeros(size(crossingPoints));
    for i = 1:size(crossingPoints,1)
        order = position(i);
        sortedCrossingPoints(order,:) = crossingPoints(i,:);
    end
    
    areasOnCrystal(counterAreas).area = sortedCrossingPoints; % save the coordinates of the area into structure areasOnCrystal
end

end
