function pointRotated = f_rotateCS_3D(point, angles)
%
% transforms coordinates [x,y,z] into a new coordinates system if provided
% 3 angles of rotation (tilts from individual axes)
%
% pointRotated = f_rotateCS_3D(point, angles)
%
% written by Venca 13/8/2013

%% Calculation 

s1 = sin(angles(1));
s2 = sin(angles(2));
s3 = sin(angles(3));

c1 = cos(angles(1));
c2 = cos(angles(2));
c3 = cos(angles(3));

rotationMatrix1 = [1, 0, 0;
                   0, c1, -s1;
                   0, s1, c1]; % rotation around x-axis
               
rotationMatrix2 = [c2, 0, s2;
                   0, 1, 0;
                   -s2, 0, c2]; % rotation around y-axis
                              
rotationMatrix3 = [c3, -s3, 0;
                   s3, c3, 0;
                   0, 0, 1]; % rotation around z-axis
               
P1 = [point(1);point(2);point(3)];
P2 = rotationMatrix1*P1;
P2 = rotationMatrix2*P2;
P2 = rotationMatrix3*P2;

pointRotated = zeros(size(point));
for i = 1:3
    pointRotated(i) = P2(i);
end

end
