% plot the orientation of crystals projected on hemisphere
clc, clear all, close all

% projection data (Equal Area Projection)
center = [0,0,0];
radius = 1;
observerAltitude = 0.7*radius; % observer's eye above the spehre center

nDivisions = 100;  % division of the hemisphere for plotting
x = zeros(nDivisions+1);
y = zeros(nDivisions+1);
z = zeros(nDivisions+1);                
                
current_folder = pwd;
open_folder = [current_folder filesep 'outputCoordinates'];
[input_filename, input_path] =  uigetfile({'*.dat';'*.*'},'File Selector',open_folder);  % 'MultiSelect', 'on',...
     
crystals = dlmread([input_path,input_filename]);
points = zeros(size(crystals,1),9);
normals = zeros(size(crystals,1),3);
intersectionsSphere = zeros(size(crystals,1),3);
intersectionsPlane = zeros(size(crystals,1),3);

% save individual vertices
for i = 1:size(crystals,1)
    points(i,:) = [crystals(i,3),crystals(i,4),crystals(i,5),...
                   crystals(i,7),crystals(i,8),crystals(i,9),...
                   crystals(i,11),crystals(i,12),crystals(i,13)]; % x1,y1,z1, x1,y1,z1, x1,y1,z1 - one crystal on each row
end

% find normals
for i = 1:size(crystals,1)
    normals(i,:) = cross(points(i,1:3)-points(i,4:6), points(i,1:3)-points(i,7:9));
end

% find intersection of normals and sphere
for i = 1:size(crystals,1)
    actualIntersection = f_intersectLineSphere([center, normals(i,:)], [center, radius]);
    for j = 1:2
        if actualIntersection(j,3) < 0 % choose those points located at z < 0
            intersectionsSphere(i,:) = actualIntersection(j,:);
        end
    end
end

% find intersection of normals and plane
for i = 1:size(crystals,1)
    intersectionsPlane(i,:) = f_planeLineIntersect([0,0,1],[0,0,-radius],[0,0,observerAltitude],intersectionsSphere(i,:));
end

% build a hemisphere
counterPsi = 0;
for psi = pi/2:pi/nDivisions:pi
    counterPsi = counterPsi+1;
    
    omega = 0:2*pi/nDivisions:2*pi;
    x(counterPsi,:) = center(1)+radius*cos(omega)*sin(psi);
    y(counterPsi,:) = center(2)+radius*sin(omega)*sin(psi);
    z(counterPsi,:) = center(3)+radius*cos(psi);
end
% draw the hemisphere
p = surface(x,y,z,'EdgeColor','none','FaceColor',[0.6 0.6 0.9],'FaceAlpha',0.4);
hold on
plot3(center(1),center(2),center(3)+observerAltitude,'o','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',6)
hold on
% draw the circle
theta = 0:0.01:2*pi;
v = null([0,0,1]);
radiusCircle = radius/observerAltitude*(radius+observerAltitude);
pointsCircle = repmat([0;0;-radius],1,size(theta,2))+radiusCircle*(v(:,1)*cos(theta)+v(:,2)*sin(theta));
plot3(pointsCircle(1,:),pointsCircle(2,:),pointsCircle(3,:),'k-');
% plot the intersections with sphere
for i = 1:size(crystals,1)
    plot3(intersectionsSphere(i,1),intersectionsSphere(i,2),intersectionsSphere(i,3),'.b')
end
% plot the intersections with plane
for i = 1:size(crystals,1)
    plot3(intersectionsPlane(i,1),intersectionsPlane(i,2),intersectionsPlane(i,3),'*r')
end

ax = get(p,'Parent');
set(ax,'XLim', [-radius radius], 'YLim', [-radius radius], 'ZLim', [-radius 0], 'PlotBoxAspectRatio', [1 1 1])
set(ax, 'Position',[0.1 0.1 0.8 0.8])
set(ax, 'XTick',[],'YTick',[],'ZTick',[])
box off
view(0, 30)
axis off
axis tight
axis equal
%lightHandles = light;
%set(lightHandles, 'Position', [radius*2.6, radius*0.5, radius*1.1], 'Style', 'local');
%lighting gouraud

display('Saving figure in 3D...')
eval(['print -dpng outputOrientationFigs/', [input_filename(1:end-3),'_3D.png']])
eval(['print -depsc2 outputOrientationFigs/', [input_filename(1:end-3),'_3D.eps']])
display('3D figure saved! Please press the space key...')        
pause

hold off

close all
f = figure;
set(f,'Position',[600 400 500 505])
theta = 0:0.001:2*pi;
pointsCircleX = radiusCircle*cos(theta);
pointsCircleY = radiusCircle*sin(theta);
p = plot(pointsCircleX,pointsCircleY,'-k');
hold on
for i = 1:size(crystals,1)
    plot(intersectionsPlane(i,1),intersectionsPlane(i,2),'*r')
end
ax = get(p,'Parent');
set(ax, 'Position',[0.1 0.1 0.8 0.8])
set(ax, 'XTick',[],'YTick',[],'ZTick',[])
axis off
% axis tight
axis equal
display('Saving figure in 2D...')
eval(['print -dpng outputOrientationFigs/', [input_filename(1:end-3),'_2D.png']])
eval(['print -depsc2 outputOrientationFigs/', [input_filename(1:end-3),'_2D.eps']])
display('2D figure saved! Please press the space key...')
pause
close all


